@@ -151,7 +151,7 @@ class SpiderBase(threading.Thread):
             if len(self.distribute_thread_list) == 0:
                 break
 
-            time.sleep(1)
+            time.sleep(0.5)
 
     def wait_spider_controller_done(self) -> None:
         """
@@ -167,7 +167,7 @@ class SpiderBase(threading.Thread):
             elif self.all_spider_controller_is_done():
                 break
 
-            time.sleep(1)  # 不加延迟将会导致性能问题
+            time.sleep(0.5)  # 不加延迟将会导致性能问题
 
     def wait_item_controller_done(self) -> None:
         """
@@ -183,7 +183,7 @@ class SpiderBase(threading.Thread):
             if len(self.item_controller_list) == 0:
                 break
 
-            time.sleep(1)
+            time.sleep(0.5)
 
     def stop_all_spider_controller(self) -> None:
         """
@@ -198,7 +198,7 @@ class SpiderBase(threading.Thread):
             if self.all_spider_controller_is_done():
                 break
 
-            time.sleep(0.1)
+            time.sleep(0.5)
 
     def all_distribute_thread_is_done(self) -> bool:
         """
