@@ -49,7 +49,7 @@ class ClientHeart:
         """
         from palp.conn import redis_conn
 
-        while not self.all_client_is_waiting:
+        while not self.stop and not self.all_client_is_waiting:
 
             all_client_is_waiting = True
 
@@ -59,6 +59,9 @@ class ClientHeart:
                 if not lock.lock_success:
                     continue
 
+                # 获取失败的客户端
+                failed_client = [i.decode() for i in redis_conn.smembers(settings.REDIS_KEY_HEARTBEAT_FAILED)]
+
                 # 上锁成功则判断客户端运行情况
                 for client_name, detail in redis_conn.hgetall(settings.REDIS_KEY_HEARTBEAT).items():
                     client_name = client_name.decode()
@@ -66,7 +69,7 @@ class ClientHeart:
 
                     # 校验 2 次失败则为客户端关闭
                     if int(time.time()) - detail['time'] - self.beating_time > 1:
-                        if redis_conn.sismember(settings.REDIS_KEY_HEARTBEAT_FAILED, client_name):
+                        if client_name in failed_client:
                             logger.warning(f"该客户端异常关闭：{client_name}")
                             redis_conn.srem(settings.REDIS_KEY_HEARTBEAT_FAILED, client_name)
                             redis_conn.hdel(settings.REDIS_KEY_HEARTBEAT, client_name)
@@ -82,14 +85,14 @@ class ClientHeart:
                                 master_detail['name'] = self.client_name
                                 redis_conn.set(settings.REDIS_KEY_MASTER, json.dumps(master_detail, ensure_ascii=False))
                     else:
-                        if redis_conn.sismember(settings.REDIS_KEY_HEARTBEAT_FAILED, client_name):
+                        if client_name in failed_client:
                             redis_conn.srem(settings.REDIS_KEY_HEARTBEAT_FAILED, client_name)
 
                         if detail['waiting'] is False:
                             all_client_is_waiting = False
                         logger.debug(f"心跳正常：{client_name}")
 
-                # 如果所有客户端都无任务，则结束
+                # 如果所有客户端都无任务进行，并且任务分发完毕，则结束
                 if all_client_is_waiting and self.master_distribute_thread_is_done():
                     logger.debug("所有客户端都已挂起，即将停止")
                     self.stop_all_client()
